 !
 !  NAME:
 !  	test_ir.f
 !
 !  PURPOSE:
 !	Test the spica_read_1a_mod module for IR data
 ! 	After compilation, use the following command:
 !	 ./test_ir 1AIR_full_path
 !
 ! Author:
 !   Nicolas Chapron
 !     CNRS | LATMOS - Laboratoire Atmospheres, Milieux, Observations Spatiales.
 !     11 boulevard d'Alembert
 !     78280 Guyancourt
 !     France
 !     Tel. 33-(0) 1 80 28 50 57
 !     Email. nicolas.chapron@latmos.ipsl.fr
 !
 !  SVN Revision:
 !      $Rev: 2365 $
 !      $Author: chapron $
 !      $Date: 2014-10-30 16:01:18 +0100 (Jeu, 30 oct 2014) $
 !

program test

    ! Definitions and declarations
    use spica_read_1a_mod
    integer i
    type(struc_1AFile) :: File1A
    character(len=2048) filename

    ! File to read:
    call get_command_argument(1,filename)

    ! Read the 1A level, create the structture
    File1A = spica_read_1A(filename,1)

    !! Print some data
    print *, '===== Observation parameters ====='
    print *,File1A%Parameters%peltier
    print *,File1A%Parameters%uvon
    print *,File1A%Parameters%soiron
    print *,File1A%Parameters%exit
    print *,File1A%Parameters%source
    print *,File1A%Parameters%gain
    print *,File1A%Parameters%dac
    print *,File1A%Parameters%dots
    print *,File1A%Parameters%ndots
    print *,File1A%Parameters%time
    print *,File1A%Parameters%gainboost
    print *,File1A%Parameters%dets

    print *, '===== Observation information ====='
    print *,File1A%Info%Instrument
    print *,File1A%Info%obstype
    print *,File1A%Info%begins
    print *,File1A%Info%ends
    print *,File1A%Info%orbit
    print *,File1A%Info%seq
    print *,File1A%Info%naxis1
    print *,File1A%Info%naxis2
    print *,File1A%Info%naxis3
    print *,File1A%Info%status
    print *,File1A%Info%nb_spectrum
    print *,File1A%Info%nb_points
    print *,File1A%Info%nb_channels
    print *,File1A%Info%nb_blocks
    print *,File1A%Info%size_block

    print *, '===== Temperatures sample ====='
    do, i=10,20
        print *, File1A%Parameters%t_aotf(i)
    enddo

    print *, '===== Geometry information ====='
    print *,File1A%GeoInfo%target
    print *,File1A%GeoInfo%slitcenter(1)
    print *,File1A%GeoInfo%slitcenter(2)
    print *,File1A%GeoInfo%irshift
    print *,File1A%GeoInfo%slitcenter(1)
    print *,File1A%GeoInfo%slitcenter(2)    
    print *,File1A%GeoInfo%sunlat
    print *,File1A%GeoInfo%sunlong
    print *,File1A%GeoInfo%sundist
    print *,File1A%GeoInfo%sunls
    print *,File1A%GeoInfo%sunra
    print *,File1A%GeoInfo%sundec

    print *, '===== Geometry records sample ====='
    print *,File1A%Geo%Record%time(1)
    print *,File1A%Geo%Record%number(1)

    print *, '===== Geometry of the spacecraft ====='
    print *,File1A%Geo%Spacecraft%lat(100)
    print *,File1A%Geo%Spacecraft%long(100)
    print *,File1A%Geo%Spacecraft%alt(100)
    print *,File1A%Geo%Spacecraft%sza(100)

    print *, '===== CleanData sample ====='
    print *,File1A%CleanData(10,100:200,1)

    print *, '===== WL sample ====='
    print *,File1A%WAVELENGTH(10,100:200,1)

    print *, '===== RAW sample ====='
    print *,File1A%RAW(10,100:200,1)

end program test
